# AppEEARS API Tutorials in R
---
# Objective:
This repository contains R tutorials for working with the AppEEARS API. The tutorials will help users understand how to use R to connect to the AppEEARS API. Topics covered include connecting to the AppEEARS API, querying the list of available products, submitting requests, downloading requests, using the AppEEARS Quality API, and importing the results into R for visualization. 
The repository includes both html tutorials and the source code used to generate the tutorials. If you are interested in browsing through this topic in an easy-to-read format, check out the .html Tutorials. To download the source code and execute the tutorials yourself, check out the R Markdown files.
## Tutorials:  
 - [Getting Started with the AppEEARS API Area Request](https://git.earthdata.nasa.gov/projects/LPDUR/repos/appeears-api-getting-started_r/browse/AppEEARS_API_Area_R.Rmd) shows how to use R to submit and download an area request.
 - [Getting Started with the AppEEARS API Point Request](https://git.earthdata.nasa.gov/projects/LPDUR/repos/appeears-api-getting-started_r/browse/AppEEARS_API_Point_R.Rmd) shows how to use R to submit and download a point request.

## Products Used:	
	
**1. [MCD15A3H.006](https://doi.org/10.5067/MODIS/MCD15A3H.006): Combined MODIS Leaf Area Index (LAI) (500m, 4 day)** 	
	     			
**2. [MOD11A2.006](https://doi.org/10.5067/MODIS/MOD11A2.006): Terra MODIS Land Surface Temperature (1000m, 8 day)**   
 				
**3. [SRTMGL1_NC.003](https://doi.org/10.5067/MEaSUREs/SRTM/SRTMGL1.003): NASA MEaSUREs Shuttle Radar Topography Mission (SRTM) Version 3 Digital Elevation Model (30m, static)**     

---
# Prerequisites:
+ Disclaimer: These tutorials have been tested on Windows using R Version 4.0.1 and the specifications identified below.* 
	  
	+ Required packages:
	  + `getPass`  
	  + `httr`  
	  + `jsonlite`  
	  + `warnings` 
	+ Additional requirements for AppEEARS area request:
	  + `geojsonio`
	  + `geojsonR`
	  + `rgdal` 
	  + `sp` 
	+ To read and visualize the GeoTIFF and tabular data:
	  + `ggplot2`    
	  + `raster` 			
	  + `rasterVis`
	  + `dplyr`        
	  + `tidyr`
	  + `readr`  
	  + `RColorBrewer`			
  
+ A [NASA Earthdata Login](https://urs.earthdata.nasa.gov/) account is required to login to the AppEEARS API and submit a request . You can create an account at the link provided.
---
# Procedures:
## Getting Started:
> #### - Copy/clone/download [AppEEARS API Getting Started in R Repository](https://git.earthdata.nasa.gov/rest/api/latest/projects/LPDUR/repos/appeears-api-getting-started_r/archive?format=zip) from the LP DAAC Data User Resources Repository.  
 
## Environment Setup: 
> #### 1.   Update R. 
> - Windows
> 	- Install and load installr: 
>		- `Install.packages("installr");library(installr)`
> 	- Copy/Update the existing packages to the new R installation"
>		- `UpdateR()`
> - Mac  
> 	- Go to https://cloud.r-project.org/bin/macosx/.
> 	- Download the latest release (R-4.0.1.pkg) and finish the installation.
> 	- To update packages, go to Tools > Check for Package Updates. If updates are available, select All, and click Install Updates.
> #### 2.   Download any of the packages that you are missing them using the `install.packages('package name')` command in the console. You can download multiple packages using the `install.packages(c('package #1', 'package #2',...))`.
---
# AppEEARS Information:
To access AppEEARS, visit: https://lpdaacsvc.cr.usgs.gov/appeears/.   
For comprehensive documentation of the full functionality of the AppEEARS API, please see the AppEEARS [API Documentation](https://lpdaacsvc.cr.usgs.gov/appeears/api/).

---
# Contact Information:
#### Authors: Mahsa Jami¹, Cole Krehbiel¹  
**Contact:** LPDAAC@usgs.gov  
**Voice:** +1-866-573-3222  
**Organization:** Land Processes Distributed Active Archive Center (LP DAAC)  
**Website:** https://lpdaac.usgs.gov/  
**Date last modified:** 06-10-2020  

¹KBR, Inc., contractor to the U.S. Geological Survey, Earth Resources Observation and Science (EROS) Center,  
 Sioux Falls, South Dakota, USA. Work performed under USGS contract G15PD00467 for LP DAAC².  
²LP DAAC Work performed under NASA contract NNG14HH33I.

